==> belenios_1.19%2bdfsg.orig.tar.xz: belenios-1.19/src/web/server/common/web_serializable_builtin_j.mli <==
(**************************************************************************)
(*                                BELENIOS                                *)
(*                                                                        *)
(*  Copyright © 2012-2021 Inria                                           *)
(*                                                                        *)
(*  This program is free software: you can redistribute it and/or modify  *)
(*  it under the terms of the GNU Affero General Public License as        *)
(*  published by the Free Software Foundation, either version 3 of the    *)
(*  License, or (at your option) any later version, with the additional   *)
(*  exemption that compiling, linking, and/or using OpenSSL is allowed.   *)
(*                                                                        *)
(*  This program is distributed in the hope that it will be useful, but   *)
(*  WITHOUT ANY WARRANTY; without even the implied warranty of            *)
(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *)
(*  Affero General Public License for more details.                       *)
(*                                                                        *)
(*  You should have received a copy of the GNU Affero General Public      *)
(*  License along with this program.  If not, see                         *)
(*  <http://www.gnu.org/licenses/>.                                       *)
(**************************************************************************)

open Web_serializable_builtin_t

(** {1 Serializers for type datetime} *)

val write_datetime : Bi_outbuf.t -> datetime -> unit
val read_datetime : Yojson.Safe.lexer_state -> Lexing.lexbuf -> datetime

(** {1 Serializers for type user_or_id} *)

val write_user_or_id : (Bi_outbuf.t -> 'a -> unit) -> Bi_outbuf.t -> 'a user_or_id -> unit
val read_user_or_id : (Yojson.Safe.lexer_state -> Lexing.lexbuf -> 'a) -> Yojson.Safe.lexer_state -> Lexing.lexbuf -> 'a user_or_id

==> belenios_1.20%2bdfsg.orig.tar.xz: belenios-1.20/src/web/server/common/web_serializable_builtin_j.mli <==
(**************************************************************************)
(*                                BELENIOS                                *)
(*                                                                        *)
(*  Copyright © 2012-2021 Inria                                           *)
(*                                                                        *)
(*  This program is free software: you can redistribute it and/or modify  *)
(*  it under the terms of the GNU Affero General Public License as        *)
(*  published by the Free Software Foundation, either version 3 of the    *)
(*  License, or (at your option) any later version, with the additional   *)
(*  exemption that compiling, linking, and/or using OpenSSL is allowed.   *)
(*                                                                        *)
(*  This program is distributed in the hope that it will be useful, but   *)
(*  WITHOUT ANY WARRANTY; without even the implied warranty of            *)
(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *)
(*  Affero General Public License for more details.                       *)
(*                                                                        *)
(*  You should have received a copy of the GNU Affero General Public      *)
(*  License along with this program.  If not, see                         *)
(*  <http://www.gnu.org/licenses/>.                                       *)
(**************************************************************************)

open Belenios_core.Signatures_core
open Web_serializable_builtin_t

(** {1 Serializers for type datetime} *)

val write_datetime : datetime writer
val read_datetime : datetime reader

(** {1 Serializers for type user_or_id} *)

val write_user_or_id : 'a writer -> 'a user_or_id writer
val read_user_or_id : 'a reader -> 'a user_or_id reader
